@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-__version__ = '0.8.5'
+__version__ = '0.9.0'
 
 from text_models.place import Mobility, MobilityWeekday, MobilityCluster
-from text_models.vocabulary import Vocabulary
+from text_models.vocabulary import Vocabulary, Tokenize
