@@ -143,7 +143,7 @@ def test_bounding_box_city():
     city = bbox.city('MX:6435')
     assert city == "16053"
     city = bbox.city("US")
-    assert city == "US"
+    assert city is None
 
 
 def test_bounding_box_city_bug():
@@ -352,4 +352,14 @@ def test_mobilityCluster():
     d = mob.inside_mobility()
     assert isinstance(d, dict)
     d = mob.inside_mobility(pandas=True)
-    assert isinstance(d, pd.DataFrame)    
\ No newline at end of file
+    assert isinstance(d, pd.DataFrame)
+
+
+def test_mobility_day_end():
+    from text_models import Mobility
+
+    day = dict(year=2020, month=7, day=17)
+    end = dict(year=2020, month=7, day=19)
+    mob = Mobility(day=day, end=end)
+    d = mob.overall(pandas=True)
+    assert d.shape[0]
\ No newline at end of file
